Gramedia / Python Common
========================

A set of common python helper classes and functions not tied to a single framework.

Everything in here should be generic as humanly possible and should only target python 3.6.

Additionally, it is desirable to keep the dependencies to an absolute minimum.

Running Tests
-------------

.. code-block:: bash

    $ make test
    $ make clean

Notes
-----

* This is pretty sparse.. Please be in the habit of adding anything you like to here.
* TODO: Documentation needs added.
* TODO: create a Makefile
